"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchSintegra = void 0;
const formatting_1 = require("../helpers/formatting");
const puppeteerHelper_1 = require("../helpers/puppeteerHelper");
const setupPuppeteer_1 = require("../helpers/setupPuppeteer");
const estados_1 = __importDefault(require("../utils/estados"));
const utils_1 = require("../utils/utils");
const NEXT_PAGE_CODE_SELECTOR = "form[name='frm_EmpresaSocios']";
const INPUT_SELECTOR = "input[name='txt_CNPJ']";
const ERROR_LABEL_SELECTOR = "font[color='#ff0000']";
const FETCH_RESULT_BUTTON_SELECTOR = "input[name='Submit']";
const getValueSelectorBy = (tableNthOfType, tdNthOfType) => `form[name='frm_EmpresaSocios'] table:nth-of-type(${tableNthOfType}) tbody tr td:nth-of-type(${tdNthOfType}) font`;
async function fetchSintegra(cnpj) {
    const browser = await setupPuppeteer_1.setupBrowser();
    try {
        const page = await setupPuppeteer_1.setupPage(estados_1.default.BAHIA.url, browser);
        await setupInitialPart(page, cnpj);
        const text = await getErrorLabelText(page);
        if (text === null || text === void 0 ? void 0 : text.includes("NÃ£o foi encontrado contribuinte cadastrado no Estado da Bahia")) {
            throw new Error("Registro não existe");
        }
        if (text === null || text === void 0 ? void 0 : text.includes("pertence a uma empresa nÃ£o inscrita no Cadastro do ICMS do Estado da Bahia")) {
            throw new Error("Não foi cadastrado como contribuinte de ICMS");
        }
        await page.waitFor(NEXT_PAGE_CODE_SELECTOR);
        const sintegra = await retrieveAndProcessValues(page);
        return buildData(sintegra);
    }
    catch (err) {
        throw err;
    }
    finally {
        await browser.close();
    }
}
exports.fetchSintegra = fetchSintegra;
async function setupInitialPart(page, cnpj) {
    const input = await page.waitFor(INPUT_SELECTOR);
    await input.type(cnpj);
    await page.click(FETCH_RESULT_BUTTON_SELECTOR);
}
async function getErrorLabelText(page) {
    return await puppeteerHelper_1.extractText(page, ERROR_LABEL_SELECTOR);
}
async function retrieveAndProcessValues(page) {
    const cnpj = await puppeteerHelper_1.extractText(page, getValueSelectorBy(2, 2));
    const ie = await puppeteerHelper_1.extractText(page, getValueSelectorBy(2, 4));
    const razaoSocial = await puppeteerHelper_1.extractText(page, getValueSelectorBy(3, 2));
    const logradouro = await puppeteerHelper_1.extractText(page, getValueSelectorBy(5, 2));
    const numero = await puppeteerHelper_1.extractText(page, getValueSelectorBy(6, 2));
    const complemento = await puppeteerHelper_1.extractText(page, getValueSelectorBy(6, 4));
    const bairro = await puppeteerHelper_1.extractText(page, getValueSelectorBy(6, 6));
    const uf = await puppeteerHelper_1.extractText(page, getValueSelectorBy(7, 2));
    const municipio = await puppeteerHelper_1.extractText(page, getValueSelectorBy(7, 4));
    const cep = await puppeteerHelper_1.extractText(page, getValueSelectorBy(7, 6));
    const enderecoEletronico = await puppeteerHelper_1.extractText(page, getValueSelectorBy(8, 2));
    const telefone = await puppeteerHelper_1.extractText(page, getValueSelectorBy(8, 4));
    const atividadeEconomica = await puppeteerHelper_1.extractText(page, getValueSelectorBy(10, 2));
    const dataDaInscricaoEstadual = await puppeteerHelper_1.extractText(page, getValueSelectorBy(11, 2));
    const usuarioSEPD = await puppeteerHelper_1.extractText(page, getValueSelectorBy(11, 4));
    const situacaoCadastralAtual = await puppeteerHelper_1.extractText(page, getValueSelectorBy(12, 2));
    const dataDestaSituacaoCadastral = await puppeteerHelper_1.extractText(page, getValueSelectorBy(12, 4));
    const condicao = await puppeteerHelper_1.extractText(page, getValueSelectorBy(13, 2));
    const observacoes = await puppeteerHelper_1.extractText(page, getValueSelectorBy(14, 2));
    const regimeDeApuracaoDeICMS = await puppeteerHelper_1.extractText(page, getValueSelectorBy(15, 2));
    const result = {
        cnpj,
        ie,
        uf,
        razaoSocial,
        logradouro,
        numero,
        complemento,
        bairro,
        municipio,
        cep,
        enderecoEletronico,
        telefone,
        atividadeEconomica,
        dataDaInscricaoEstadual,
        usuarioSEPD,
        situacaoCadastralAtual,
        dataDestaSituacaoCadastral,
        condicao,
        observacoes,
        regimeDeApuracaoDeICMS,
    };
    for (const [key, value] of Object.entries(result)) {
        result[key] = formatting_1.formatText(value);
    }
    return result;
}
function buildData(data) {
    if (utils_1.isObjectEmpty(data)) {
        throw new Error("Sem dados");
    }
    return {
        identificacao: {
            cnpj: data.cnpj,
            ie: data.ie,
            razaoSocial: data.razaoSocial,
        },
        endereco: {
            logradouro: data.logradouro,
            numero: data.numero,
            complemento: data.complemento,
            bairro: data.bairro,
            uf: data.uf,
            municipio: data.municipio,
            cep: data.cep,
            enderecoEletronico: data.enderecoEletronico,
            telefone: data.telefone,
        },
        informacoesComplementares: {
            atividadeEconomica: data.atividadeEconomica,
            dataDaInscricaoEstadual: data.dataDaInscricaoEstadual,
            usuarioSEPD: data.usuarioSEPD,
            situacaoCadastralAtual: data.situacaoCadastralAtual,
            dataDestaSituacaoCadastral: data.dataDestaSituacaoCadastral,
            condicao: data.condicao,
            observacoes: data.observacoes,
            regimeDeApuracaoDeICMS: data.regimeDeApuracaoDeICMS,
        },
    };
}
//# sourceMappingURL=sintegraBA.js.map